==> 2.1.tar.gz: filesharing/lang/fr/app.php <==
<?php


return [
	'preview-bundle'		=> 'Contenu de l\'archive',
	'bundle-preview-intro'	=> 'Here is the list of the files you can download:',
	'warning-bundle-expiration'	=> 'L\'archive expire',
	'warning-bundle-expired'	=> 'L\'archive a expiré',
	'download-all'	=> 'Tout télécharger',
	'for'	=> 'pour',
	'files'	=> 'fichier(s)',
	'no-file-in-this-bundle' => 'Aucun fichier dans cette archive',
	'maximum-filesize'	=> 'Taille maximum :',
	'preview-link'	=> 'Lien de visualisation',
	'direct-link' => 'Lien de téléchargement',
	'delete-link' => 'Lien de suppression',
	'upload-files-title' => 'Téléverser',
	'bundle-preview-title' => 'Télécharger',
	'files-list' => 'Fichiers téléversés',
	'error-title' => 'Une erreur est survenue',
	'files-count-limit' => 'Nombre maximal de fichiers atteint',
	'file-too-big' => 'Le fichier est trop lourd',
	'cannot-upload' => 'Impossible de téléverser',
	'cannot-upload-blocked-ip' => 'Vous n\'avez pas la permission de téléverser sur cette application',
	'upload-permission-required' => 'Autorisation requise pour téléverser',
	'cannot-upload-no-password' => 'You must provide a valid password in order to upload on this application',
	'password' => 'Mot de passe',
	'upload-disabled' => 'Téléversement désactivé',
	'start-new-upload' => 'Cliquez ici pour créer une nouvelle archive',
	'upload-settings' => 'Préférences',
	'upload-expiry'	=> 'Expiration',
	'upload-title'	=> 'Titre',
	'upload-description'	=> 'Description',
	'required'	=> 'Requis',
	'download-links' => 'Liens de téléchargement',
	'one-hour' => 'Une heure (1H)',
	'two-hours' => 'Deux heures (2H)',
	'six-hours' => 'Six heures (6H)',
	'twelve-hours' => 'Douze heures (12H)',
	'one-day' => 'Un jour (1J)',
	'two-days' => 'Deux jours (2J)',
	'one-week' => 'Une semaine (1S)',
	'two-weeks' => 'Deux semaines (2S)',
	'one-month' => 'Un mois (1M)',
	'three-months' => 'Trois mois (3M)',
	'six-months' => 'Six mois (6M)',
	'step'      => 'Etape',
	'leave-empty'   => 'Laissez vide pour désactiver mot de passe',
	'back'  => 'Retour',
	'start-uploading'   => 'Téléverser vos fichiers',
	'bundle-password'   => 'Mot de passe',
	'complete-upload'   => 'Compléter l\'archive',
	'no-file'   => 'Aucun fichier téléversé',
	'click-to-remove'   => 'Cliquez pour supprimer ce fichier',
	'confirm-delete'    => 'Voulez-vous supprimer ce fichier ?',
	'confirm-complete'   => 'Voulez-vous compléter cette archive ? Elle sera verrouillée et ne pourra plus être modifiée.',
	'confirmation'  => 'Confirmation',
	'cancel'    => 'Annuler',
	'confirm'   => 'Confirmer',
	'bundle-locked' => 'Cette archive est close et verrouillée',
	'created-at'    => 'Créé',
	'fullsize'  => 'Total',
	'max-downloads'	=> 'Téléchargements maximum',
	'create-new-upload'	=> 'Créer une nouvelle archive',
	'page-not-found'	=> 'Page non trouvée',
	'permission-denied'	=> 'Permission refusée',
	'dropzone-text'	=> 'Déposez vos fichiers ici (ou cliquez)',
	'server-answered' => 'Le serveur a répondu avec le code {{statusCode}}.',
	'files-count-on-server' => 'Nombre de fichiers téléversés',
	'files-remaining-files' => 'Nombre de fichiers restants autorisés',
	'delete-bundle'	=> 'Supprimer l\'archive',
	'confirm-delete-bundle' => 'Voulez-vous supprimer cette archive ?',
	'bundle-expired'	=> 'Cette archive a expiré',
	'active'	=> 'Actifs',
	'expired'	=> 'Expirés',
	'existing-bundles' => 'Vos archives existantes',
	'or-create'	=> 'Nouvelle archive',
	'no-existing-bundle' => 'Aucune archive existante'


];

==> 2.3.tar.gz: filesharing/lang/fr/app.php <==
<?php


return [
	'preview-bundle'		=> 'Contenu de l\'archive',
	'bundle-preview-intro'	=> 'Here is the list of the files you can download:',
	'warning-bundle-expiration'	=> 'L\'archive expire',
	'warning-bundle-expired'	=> 'L\'archive a expiré',
	'download-all'	=> 'Tout télécharger',
	'for'	=> 'pour',
	'files'	=> 'fichier(s)',
	'no-file-in-this-bundle' => 'Aucun fichier dans cette archive',
	'maximum-filesize'	=> 'Taille maximum :',
	'preview-link'	=> 'Lien de visualisation',
	'direct-link' => 'Lien de téléchargement',
	'delete-link' => 'Lien de suppression',
	'upload-files-title' => 'Téléverser',
	'bundle-preview-title' => 'Télécharger',
	'files-list' => 'Fichiers téléversés',
	'error-title' => 'Une erreur est survenue',
	'files-count-limit' => 'Nombre maximal de fichiers atteint',
	'file-too-big' => 'Le fichier est trop lourd',
	'cannot-upload' => 'Impossible de téléverser',
	'cannot-upload-blocked-ip' => 'Vous n\'avez pas la permission de téléverser sur cette application',
	'upload-permission-required' => 'Autorisation requise pour téléverser',
	'cannot-upload-no-password' => 'You must provide a valid password in order to upload on this application',
	'password' => 'Mot de passe',
	'upload-disabled' => 'Téléversement désactivé',
	'start-new-upload' => 'Cliquez ici pour créer une nouvelle archive',
	'upload-settings' => 'Préférences',
	'upload-expiry'	=> 'Expiration',
	'upload-title'	=> 'Titre',
	'upload-description'	=> 'Description',
	'required'	=> 'Requis',
	'download-links' => 'Liens de téléchargement',
	'one-hour' => 'Une heure (1H)',
	'two-hours' => 'Deux heures (2H)',
	'six-hours' => 'Six heures (6H)',
	'twelve-hours' => 'Douze heures (12H)',
	'one-day' => 'Un jour (1J)',
	'two-days' => 'Deux jours (2J)',
	'one-week' => 'Une semaine (1S)',
	'two-weeks' => 'Deux semaines (2S)',
	'one-month' => 'Un mois (1M)',
	'three-months' => 'Trois mois (3M)',
	'six-months' => 'Six mois (6M)',
	'step'      => 'Etape',
	'leave-empty'   => 'Laissez vide pour désactiver mot de passe',
	'back'  => 'Retour',
	'start-uploading'   => 'Téléverser vos fichiers',
	'bundle-password'   => 'Mot de passe',
	'complete-upload'   => 'Compléter l\'archive',
	'no-file'   => 'Aucun fichier téléversé',
	'click-to-remove'   => 'Cliquez pour supprimer ce fichier',
	'confirm-delete'    => 'Voulez-vous supprimer ce fichier ?',
	'confirm-complete'   => 'Voulez-vous compléter cette archive ? Elle sera verrouillée et ne pourra plus être modifiée.',
	'confirmation'  => 'Confirmation',
	'cancel'    => 'Annuler',
	'confirm'   => 'Confirmer',
	'bundle-locked' => 'Cette archive est close et verrouillée',
	'created-at'    => 'Créé',
	'fullsize'  => 'Total',
	'max-downloads'	=> 'Téléchargements maximum',
	'create-new-upload'	=> 'Créer une nouvelle archive',
	'page-not-found'	=> 'Page non trouvée',
	'permission-denied'	=> 'Permission refusée',
	'dropzone-text'	=> 'Déposez vos fichiers ici (ou cliquez)',
	'server-answered' => 'Le serveur a répondu avec le code {{statusCode}}.',
	'files-count-on-server' => 'Nombre de fichiers téléversés',
	'files-remaining-files' => 'Nombre de fichiers restants autorisés',
	'delete-bundle'	=> 'Supprimer l\'archive',
	'confirm-delete-bundle' => 'Voulez-vous supprimer cette archive ?',
	'bundle-expired'	=> 'Cette archive a expiré',
	'active'	=> 'Actifs',
	'expired'	=> 'Expirés',
	'existing-bundles' => 'Vos archives existantes',
	'or-create'	=> 'Nouvelle archive',
	'no-existing-bundle' => 'Aucune archive existante',
	'authentication'	=> 'Authentification',
	'login'	=> 'Identifiant',
	'password' => 'Mot de passe',
	'do-login' => 'S\'authentifier'


];
